summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecommandhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetecommandhandler.h')
-rw-r--r--kopete/libkopete/kopetecommandhandler.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/kopete/libkopete/kopetecommandhandler.h b/kopete/libkopete/kopetecommandhandler.h
index 9632f872..aeb93529 100644
--- a/kopete/libkopete/kopetecommandhandler.h
+++ b/kopete/libkopete/kopetecommandhandler.h
@@ -45,11 +45,12 @@ typedef TQDict<Command> CommandList;
*
* The Kopete::CommandHandler can handle /action like messages
*/
-class KOPETE_EXPORT CommandHandler : public QObject
+class KOPETE_EXPORT CommandHandler : public TQObject
{
friend class ::KopeteCommandGUIClient;
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -73,7 +74,7 @@ class KOPETE_EXPORT CommandHandler : public QObject
* Kopete::CommandHandler). These commands can also be overridden by
* registering a new duplicate command.
*
* @param parent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
* accept two parameters, a TQString of arguments, and a Kopete::ChatSession
@@ -85,14 +86,14 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerCommand( TQObject *parent, const TQString &command, const char* handlerSlot,
- const TQString &help = TQString::null, uint minArgs = 0, int maxArgs = -1,
- const KShortcut &cut = 0, const TQString &pix = TQString::null );
+ void registerCommand( TQObject *tqparent, const TQString &command, const char* handlerSlot,
+ const TQString &help = TQString(), uint minArgs = 0, int maxArgs = -1,
+ const KShortcut &cut = 0, const TQString &pix = TQString() );
/**
* \brief Register a command alias.
*
* @param parent The plugin who owns this alias
* @param alias The command for the alias
* @param formatString This is the string that will be transformed into another
* command. The formatString should begin with an already existing command,
@@ -106,15 +107,15 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerAlias( TQObject *parent,
+ void registerAlias( TQObject *tqparent,
const TQString &alias,
const TQString &formatString,
- const TQString &help = TQString::null,
+ const TQString &help = TQString(),
CommandType = SystemAlias,
uint minArgs = 0,
int maxArgs = -1,
const KShortcut &cut = 0,
- const TQString &pix = TQString::null );
+ const TQString &pix = TQString() );
/**
* \brief Unregister a command.
@@ -123,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public QObject
* This function should only be called in the case of a plugin which loads and
* unloads commands dynamically.
*
* @param parent The plugin who owns this command
* @param command The command to unload
*/
- void unregisterCommand( TQObject *parent, const TQString &command );
+ void unregisterCommand( TQObject *tqparent, const TQString &command );
/**
* \brief Unregister an alias.
*
* \see unregisterCommand( TQObject *parent, const TQString &command )
* @param parent The plugin who owns this alias
* @param alias The alais to unload
*/
- void unregisterAlias( TQObject *parent, const TQString &alias );
+ void unregisterAlias( TQObject *tqparent, const TQString &alias );
/**
* \brief Process a message to see if any commands should be handled
@@ -73,7 +74,7 @@ class KOPETE_EXPORT CommandHandler : public QObject
* registering a new duplicate command.
*
- * @param parent The plugin who owns this command
+ * @param tqparent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
@@ -85,14 +86,14 @@ class KOPETE_EXPORT CommandHandler : public QObject
* \brief Register a command alias.
*
- * @param parent The plugin who owns this alias
+ * @param tqparent The plugin who owns this alias
* @param alias The command for the alias
* @param formatString This is the string that will be transformed into another
@@ -123,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public QObject
* unloads commands dynamically.
*
- * @param parent The plugin who owns this command
+ * @param tqparent The plugin who owns this command
* @param command The command to unload
*/
@@ -123,19 +124,19 @@ class KOPETE_EXPORT CommandHandler : public QObject
* \brief Unregister an alias.
*
- * \see unregisterCommand( TQObject *parent, const TQString &command )
- * @param parent The plugin who owns this alias
+ * \see unregisterCommand( TQObject *tqparent, const TQString &command )
+ * @param tqparent The plugin who owns this alias
* @param alias The alais to unload
*/